# Changelog

## [0.2.1](https://github.com/r0f1/critical_es_value/compare/v0.2.0...v0.2.1) (2025-10-14)


### Documentation

* CEV-0001 Improve Docs ([#1](https://github.com/r0f1/critical_es_value/issues/1)) ([e49baff](https://github.com/r0f1/critical_es_value/commit/e49baff46b2f38d857ea507db283a10ba326e12d))
